==> score.jsapi-0.4.16-py3-none-any.whl: score/jsapi/tpl/es6/exception.js <==
/**
 * Copyright © 2015-2017 STRG.AT GmbH, Vienna, Austria
 * Copyright © 2018 Necdet Can Ateşman, Vienna, Austria
 *
 * This file is part of the The SCORE Framework.
 *
 * The SCORE Framework and all its parts are free software: you can redistribute
 * them and/or modify them under the terms of the GNU Lesser General Public
 * License version 3 as published by the Free Software Foundation which is in the
 * file named COPYING.LESSER.txt.
 *
 * The SCORE Framework and all its parts are distributed without any WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. For more details see the GNU Lesser General Public
 * License.
 *
 * If you have not received a copy of the GNU Lesser General Public License see
 * http://www.gnu.org/licenses/.
 *
 * The License-Agreement realised between you as Licensee and STRG.AT GmbH as
 * Licenser including the issue of its valid conclusion and its pre- and
 * post-contractual effects is governed by the laws of Austria. Any disputes
 * concerning this License-Agreement including the issue of its valid conclusion
 * and its pre- and post-contractual effects are exclusively decided by the
 * competent court, in whose district STRG.AT GmbH has its registered seat, at
 * the discretion of STRG.AT GmbH also the competent court, in whose district the
 * Licensee has his registered seat, an establishment or assets.
 */
/* eslint-disable */
/* tslint:disable */

export class Exception extends Error {

    static classes = {};

    static defineCallbacks = [];

    static define = function(name, parentName) {
        const NewException = function(message) {
            if (parentName) {
                Exception.classes[parentName].call(this, message);
            } else {
                Exception.call(this, message);
            }
        };
        NewException.prototype = Object.create(Exception.prototype);
        NewException.prototype.name = name;
        Exception.classes[name] = NewException;
        for (let i = 0; i < Exception.defineCallbacks.length; i++)  {
            Exception.defineCallbacks[i](name, NewException);
        }
        return NewException;
    };

    static onDefine = function(callback) {
        Exception.defineCallbacks.push(callback);
    };

    constructor(message) {
        super(message);
        this.name = this.constructor.name;
        if (typeof Error.captureStackTrace === 'function') {
            Error.captureStackTrace(this, this.constructor);
        } else { 
            this.stack = (new Error(message)).stack; 
        }
    }

}

export default Exception;

==> score.jsapi-0.4.20-py3-none-any.whl: score/jsapi/tpl/es6/exception.js <==
/**
 * Copyright © 2015-2017 STRG.AT GmbH, Vienna, Austria
 * Copyright © 2018 Necdet Can Ateşman, Vienna, Austria
 *
 * This file is part of the The SCORE Framework.
 *
 * The SCORE Framework and all its parts are free software: you can redistribute
 * them and/or modify them under the terms of the GNU Lesser General Public
 * License version 3 as published by the Free Software Foundation which is in the
 * file named COPYING.LESSER.txt.
 *
 * The SCORE Framework and all its parts are distributed without any WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. For more details see the GNU Lesser General Public
 * License.
 *
 * If you have not received a copy of the GNU Lesser General Public License see
 * http://www.gnu.org/licenses/.
 *
 * The License-Agreement realised between you as Licensee and STRG.AT GmbH as
 * Licenser including the issue of its valid conclusion and its pre- and
 * post-contractual effects is governed by the laws of Austria. Any disputes
 * concerning this License-Agreement including the issue of its valid conclusion
 * and its pre- and post-contractual effects are exclusively decided by the
 * competent court, in whose district STRG.AT GmbH has its registered seat, at
 * the discretion of STRG.AT GmbH also the competent court, in whose district the
 * Licensee has his registered seat, an establishment or assets.
 */
/* eslint-disable */
/* tslint:disable */

export class Exception extends Error {

    static classes = {};

    static defineCallbacks = [];

    static define = function(name, parentName) {
        const parent = parentName ? Exception.classes[parentName] : Exception;
        const NewException = class extends parent {};
        NewException.prototype.name = name;
        Exception.classes[name] = NewException;
        for (let i = 0; i < Exception.defineCallbacks.length; i++)  {
            Exception.defineCallbacks[i](name, NewException);
        }
        return NewException;
    };

    static onDefine = function(callback) {
        Exception.defineCallbacks.push(callback);
    };

    constructor(message) {
        super(message);
        this.name = this.constructor.name;
        if (typeof Error.captureStackTrace === 'function') {
            Error.captureStackTrace(this, this.constructor);
        } else { 
            this.stack = (new Error(message)).stack; 
        }
    }

}

export default Exception;
